@@ -295,6 +295,7 @@ module mesa_interface
     subroutine  set_init_options(id, &
                                 mass, &
                                 mesa_dir_in, &
+                                mesa_data_dir_in, &
                                 output_folder, &
                                 inlist, &
                                 metallicity,&
@@ -305,7 +306,7 @@ module mesa_interface
                                 temp_dir &
                                 )
         integer, intent(in) :: id
-        character(len=*), intent(in) :: mesa_dir_in, output_folder, inlist, gyre_in, temp_dir
+        character(len=*), intent(in) :: mesa_dir_in, mesa_data_dir_in, output_folder, inlist, gyre_in, temp_dir
         real(dp), intent(in) :: mass, metallicity,&
                                 max_age_stop_condition, &
                                 min_timestep_stop_condition
@@ -325,6 +326,8 @@ module mesa_interface
         call const_init(mesa_dir_in, ierr)
         if (failed('const_init',ierr)) return 
 
+        mesa_data_dir = mesa_data_dir_in
+
         s% inlist_fname = inlist
 
         s% job% mesa_dir = mesa_dir_in
@@ -340,8 +343,8 @@ module mesa_interface
         s% history_interval = -1
         s% profile_interval = -1
         s% photo_interval = -1
-        s% terminal_interval = -1
-        s% write_header_frequency =-1
+        s% terminal_interval = 1
+        s% write_header_frequency = 100
 
         mesa_temp_caches_dir = trim(temp_dir) 
 
@@ -579,7 +582,6 @@ module mesa_interface
         s% max_age = s% star_age + delta_t
         s% num_adjusted_dt_steps_before_max_age =  -1
 
-        s%dt_next = delta_t * secyer
         evolve_loop: do 
             call do_evolve_one_step(id, result, ierr)
             if (result /= keep_going) then
@@ -595,6 +597,7 @@ module mesa_interface
 
         ! In case you want to evolve further
         s% max_age = old_age
+        if(s% dt_next==0) s% dt_next = s% dt
 
         s% doing_first_model_of_run = .false.
 
